@@ -12,7 +12,10 @@ gtk.gdk.threads_init()
 import gtk.glade
 import datetime
 import mnotes_framework
+import mnotes_prefs
+import mnotes_sync
 import pango
+#import gtkhtml2
 
 try:
   import hildon
@@ -37,12 +40,12 @@ class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.2.7"
+  __version__ = "0.2.8"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
-    '/usr/lib/mnotes/ui/mnotes.glade',
-    #'ui/mnotes.glade',
+    #'/usr/lib/mnotes/ui/mnotes.glade',
+    'ui/mnotes.glade',
   ]
 
   def __init__(self,app,context):
@@ -103,6 +106,7 @@ class mNotes(object):
     self._textwin = self._widgetTree.get_widget("TextView")
     self._drawwin = self._widgetTree.get_widget("DrawingView")
 
+    self._bTitleText = self._widgetTree.get_widget("bTitleText")
     self._bTitlePict = self._widgetTree.get_widget("bTitlePict")
     self._bTitleDraw= self._widgetTree.get_widget("bTitleDraw")
 
@@ -126,6 +130,8 @@ class mNotes(object):
     }
     self._widgetTree.signal_autoconnect(callbackMapping)
 
+    self._prefs = mnotes_prefs.mPrefs()
+
     self._load_hpane_position()
     self._current_selection_iter = None
 
@@ -167,6 +173,7 @@ class mNotes(object):
     if view == 0:
       self._imagewin.hide()
       self._textwin.show()
+      self._window.set_focus(self._editor)
       self._drawwin.hide()
     elif view == 1:
       self._imagewin.hide()
@@ -248,12 +255,18 @@ class mNotes(object):
 
       if self._current_note.type == 0:
         buffer = self._editor.get_buffer()
-        start, end = buffer.get_bounds ()      
-        self._current_note.description = buffer.get_text(start,end)
+        start, end = buffer.get_bounds ()
+        if self._bTitleText.get_text() != 'Untitled':
+          self._current_note.title = self._bTitleText.get_text()
+          self._current_note.description = buffer.get_text(start,end)
+        else:
+          splitted = buffer.get_text(start,end).split('\n')
+          self._current_note.title = splitted[0]
+          self._current_note.description = '\n'.join(splitted[1::])
       elif self._current_note.type == 1:
-        self._current_note.description = self._bTitleDraw.get_text()
+        self._current_note.title = self._bTitleDraw.get_text()
       elif self._current_note.type == 2:
-        self._current_note.description = self._bTitlePict.get_text()
+        self._current_note.title = self._bTitlePict.get_text()
       self._current_note.save_to_db()
 
       if self._current_note.type == 1:
@@ -282,7 +295,13 @@ class mNotes(object):
       self._current_selection_iter = selection_iter
       self._current_note = mnotes_framework.Note(uuid)
       self._current_note.draw_loaded = False
+      self._bTitleText.set_text(self._current_note.title)
       self._editor.get_buffer().set_text(self._current_note.description)
+      #gtkhtml??
+      #self._editor_document.open_stream('text/html')
+      #self._editor_document.write_stream(self._current_note.description)
+      #self._editor_document.close_stream()
+
       #Load photo
       if (self._current_note.type == 2) :
         self._bTitlePict.set_text(self._current_note.title)
@@ -413,11 +432,12 @@ class mNotes(object):
     return False
 
   def _children_color_bg(self,widget):
-    if (type(widget)!=gtk.DrawingArea) and (type(widget)!=gtk.Image) and (type(widget)!=gtk.Label) and (type(widget)!=gtk.TreeView) and (type(widget)!=gtk.VSeparator)  and (type(widget)!=gtk.Entry) and (type(widget)!=gtk.CellView) and (type(widget)!=gtk.Calendar):
-      widget.modify_bg(gtk.STATE_NORMAL,gtk.gdk.Color(60000,60000,60000))
-      widget.modify_bg(gtk.STATE_INSENSITIVE,gtk.gdk.Color(60000,60000,60000))
-      for child in widget.get_children():
-        self._children_color_bg(child)
+    if self._prefs.get_value('override_theme') == 'True':
+      if (type(widget)!=gtk.DrawingArea) and (type(widget)!=gtk.Image) and (type(widget)!=gtk.Label) and (type(widget)!=gtk.TreeView) and (type(widget)!=gtk.VSeparator)  and (type(widget)!=gtk.Entry) and (type(widget)!=gtk.CellView) and (type(widget)!=gtk.Calendar):
+        widget.modify_bg(gtk.STATE_NORMAL,gtk.gdk.Color(60000,60000,60000))
+        widget.modify_bg(gtk.STATE_INSENSITIVE,gtk.gdk.Color(60000,60000,60000))
+        for child in widget.get_children():
+          self._children_color_bg(child)
 
   def _idle_setup(self):
     """
@@ -438,6 +458,15 @@ class mNotes(object):
 
     self._editor = self._widgetTree.get_widget("Editor")
     self._editor.get_buffer().set_text('Welcome to mnotes !')
+
+    # gtkhtm????
+    #    parent = self._widgetTree.get_widget("Editor").get_parent()
+    #    self._widgetTree.get_widget("Editor").destroy()
+    #    self._editor = gtkhtml2.View()
+    #    parent.add(self._editor)
+    #    self._editor_document = gtkhtml2.Document()
+    #    self._editor.set_document(self._editor_document)
+
     self._photoview =self._widgetTree.get_widget("PhotoView")
     self._photoview.connect('size-allocate',self.on_size_allocate)
 
@@ -678,6 +707,19 @@ class mNotes(object):
     accel_group = gtk.AccelGroup ()
     self._window.add_accel_group (accel_group)
 
+    #Sync
+    item = gtk.ImageMenuItem (gtk.STOCK_REFRESH, accel_group)
+    item.get_child().set_text('Launch Google Sync')
+    item.connect ("activate", self.launch_sync_bg)
+    item.show ()
+    self.menubar.append (item)
+
+    #Preferences
+    item = gtk.ImageMenuItem (gtk.STOCK_PREFERENCES, accel_group)
+    item.connect ("activate", self._show_prefs_ui)
+    item.show ()
+    self.menubar.append (item)
+
     #Separator
     item = gtk.SeparatorMenuItem ()
     item.show ()
@@ -689,6 +731,33 @@ class mNotes(object):
     item.show ()
     self.menubar.append (item)
 
+  def launch_sync_bg(self,widget):
+    if ask_dialogue(self._window,'Sync is actually completly bugged, are you sure to continue ?')==True:
+      self._sync_thread = threading.Thread(target=self._launch_sync)
+      self._sync_thread.start()
+
+  def _launch_sync(self):
+    self._save_current_note()
+    sync = mnotes_sync.GSync(str(self._prefs.get_value('google_login')).encode(),str(self._prefs.get_value('google_password')).encode())
+    sync.sync_docs()
+    if sync.get_last_error()!=None:
+      self.warn(sync.get_last_error())
+    self._load_noteslist_bg()
+  
+  def warn(self,message):
+    gtk.gdk.threads_enter()
+    dialog = gtk.MessageDialog(gtk.Window(),
+                    gtk.DIALOG_MODAL,
+                    gtk.MESSAGE_ERROR,
+                    gtk.BUTTONS_OK,
+                    message)
+    rc = dialog.run ()
+    dialog.destroy ()
+    gtk.gdk.threads_leave()
+
+  def _show_prefs_ui(self,widget):
+    self._prefs.show_ui()
+
   def _on_key_press(self, widget, event, *args):
     """
     @note Hildon specific
